==> nsc-2.0.6-132-GA.update.tgz: var/webconfig/SAFe/application/views/safe_iframe_notice.php <==
<?php
/** vim: set tabstop=4 softtabstop=4 shiftwidth=4 textwidth=80 smarttab expandtab: **/
/** coding: utf-8: **/
/*
 * Copyright (C) 2012  Sangoma Technologies Corp.
 * All Rights Reserved.
 *
 * Author(s)
 * your name <your_name@sangoma.com>
 *
 * This code is Sangoma Technologies Confidential Property.
 * Use of and access to this code is covered by a previously executed
 * non-disclosure agreement between Sangoma Technologies and the Recipient.
 * This code is being supplied for evaluation purposes only and is not to be
 * used for any other purpose.
*/
/*
 * basic code of this views:
*/
global $SAFE_WC_HELPER;
ob_start();
        WebHeader('__TITLE__', 'wizard', '<!--HEAD_ADD-->', '__ONLOAD__');
        // HEAD_ADD is added before the javascript load and after the ccs load.
        // __ONLOAD__ is unused, better to insert before </head>
        $SAFE_WC_HELPER['header'] = ob_get_contents();
        ob_end_clean();
        ob_start();
        WebFooter();
        $SAFE_WC_HELPER['footer'] = ob_get_contents();
        ob_end_clean();
$iframe_header = SAFE_WC_HEADER();
//remove content after body
$iframe_header =  substr($iframe_header,0,strpos($iframe_header,'<body>')).'<body>';
$iframe_footer = "</body></html>";          

echo $iframe_header;
?>
<script type="text/javascript">
var system_status_flag = '';
var config_status_flag = '';
var warning_status_flag = '';
<?php
if(isset($system)){
    if ($system['status'] == 'ok' ){?>
        	  window.parent.$('#system_status').html('<img src="/SAFe/images/silk/accept.png" style="vertical-align:middle;"> <a href="<?php echo $system['url'];?>"><?php echo $system['description'];?></a>');
        	  window.parent.$('#system_status').css('color','green');
        	  window.parent.$('#system_status').css('display','block');
        	  system_status_flag = 'green';
    	<?php  
       }else{?>
        	  window.parent.$('#system_status').html('<img src="/SAFe/images/silk/stop.png" style="vertical-align:middle;"> <a href="<?php echo $system['url'];?>" style="color:red;"><?php echo $system['description'];?></a>');
        	  window.parent.$('#system_status').css('color','red');
        	  window.parent.$('#system_status').css('display','block');
        	  system_status_flag = 'red';
    	  <?php 
       }; 
}
if(isset($configuration)){
    if ($configuration['status'] == 'ok' ){?>
        	window.parent.$('#config_status').html('<img src="/SAFe/images/silk/accept.png" style="vertical-align:middle;"> <a href="<?php echo $configuration['url'];?>"><?php echo $configuration['description'];?></a>');
            window.parent.$('#config_status').css('color','green');
            window.parent.$('#config_status').css('display','block');
            config_status_flag = 'green';
        <?php  
    }else{?>
    	   window.parent.$('#config_status').html('<img src="/SAFe/images/silk/stop.png" style="vertical-align:middle;"> <a href="<?php echo $configuration['url'];?>" style="color:red;"><?php echo $configuration['description'];?></a>');
           window.parent.$('#config_status').css('color','red');
           window.parent.$('#config_status').css('display','block');
           config_status_flag = 'red';
        <?php 
    };
} 
?>
</script>
<link rel="stylesheet" type="text/css" href="/SAFe/css/safe.css" />
<script type="text/javascript" src="/SAFe/js/jquery.form.js"></script>
<script type="text/javascript" src="/SAFe/js/safe.js"></script>
<script type="text/javascript">
(function($){
	if(system_status_timer === null){
		system_status_fresh(true,ajax_running_id);
		system_status_timer = setInterval(function(){ajax_running_id = ajax_running_id+1;system_status_fresh(true,ajax_running_id);}, 5000);//5s
	}
})(jQuery);
</script> 
<script type='text/javascript'>
//check if the main page js was loaded.
function main_load_safe_js(){
	if ('undefined' !== typeof window.parent) {
		if ('undefined' == typeof window.parent.safe_message_box) {
		    //load css
			var css = window.parent.$("<link>");
		    css.attr({
		      rel:  "stylesheet",
		      type: "text/css",
		      href: "/SAFe/css/safe.css"
		    });
		    window.parent.$("head").append(css);
		    //load safe.js
			var head= window.parent.document.getElementsByTagName('head')[0];
		    var script= window.parent.document.createElement('script');
		    script.type= 'text/javascript';
		    script.src= '/SAFe/js/safe.js';
		    script.defer = true;
		    script.async = true;
		    head.appendChild(script);
		    script.onload=function() {
		    	//console.log('safe.js was loaded.');
		    }
		}
	}
}
$(document).ready(function(){
    if ('undefined' !== typeof window.parent) {
    	if(window.parent.$().jquery == '1.3.2'){
			// Load required javascript files
			window.parent.$.getScript("/SAFe/js/jquery/jquery-1.8.2.min.js", function(data, textStatus) {
			});
			window.parent.$.getScript("/SAFe/js/jquery-ui/jquery-ui-1.9.1.custom.min.js", function(data, textStatus) {
				main_load_safe_js();
			});
	   }else{
		   main_load_safe_js();
	   }
    }
});
</script>
<?php 
    echo $iframe_footer;      
?>

==> nsc-2.1.0-27-GA.update.tgz: var/webconfig/SAFe/application/views/safe_iframe_notice.php <==
<?php
/** vim: set tabstop=4 softtabstop=4 shiftwidth=4 textwidth=80 smarttab expandtab: **/
/** coding: utf-8: **/
/*
 * Copyright (C) 2012  Sangoma Technologies Corp.
 * All Rights Reserved.
 *
 * Author(s)
 * your name <your_name@sangoma.com>
 *
 * This code is Sangoma Technologies Confidential Property.
 * Use of and access to this code is covered by a previously executed
 * non-disclosure agreement between Sangoma Technologies and the Recipient.
 * This code is being supplied for evaluation purposes only and is not to be
 * used for any other purpose.
*/
/*
 * basic code of this views:
*/
global $SAFE_WC_HELPER;
ob_start();
        WebHeader('__TITLE__', 'wizard', '<!--HEAD_ADD-->', '__ONLOAD__');
        // HEAD_ADD is added before the javascript load and after the ccs load.
        // __ONLOAD__ is unused, better to insert before </head>
        $SAFE_WC_HELPER['header'] = ob_get_contents();
        ob_end_clean();
        ob_start();
        WebFooter();
        $SAFE_WC_HELPER['footer'] = ob_get_contents();
        ob_end_clean();
$iframe_header = SAFE_WC_HEADER();
//remove content after body
$iframe_header =  substr($iframe_header,0,strpos($iframe_header,'<body>')).'<body>';
$iframe_footer = "</body></html>";          

echo $iframe_header;
?>
<script type="text/javascript">
var system_status_flag = '';
var config_status_flag = '';
var warning_status_flag = '';
<?php
if(isset($system)){
    if ($system['status'] == 'ok' ){?>
        	  window.parent.$('#system_status').html('<img src="/SAFe/images/silk/accept.png" style="vertical-align:middle;"> <a href="<?php echo $system['url'];?>"><?php echo $system['description'];?></a>');
        	  window.parent.$('#system_status').css('color','green');
        	  window.parent.$('#system_status').css('display','block');
        	  system_status_flag = 'green';
    	<?php  
       }else{?>
        	  window.parent.$('#system_status').html('<img src="/SAFe/images/silk/stop.png" style="vertical-align:middle;"> <a href="<?php echo $system['url'];?>" style="color:red;"><?php echo $system['description'];?></a>');
        	  window.parent.$('#system_status').css('color','red');
        	  window.parent.$('#system_status').css('display','block');
        	  system_status_flag = 'red';
    	  <?php 
       }; 
}
if(isset($configuration)){
    if ($configuration['status'] == 'ok' ){?>
        	window.parent.$('#config_status').html('<img src="/SAFe/images/silk/accept.png" style="vertical-align:middle;"> <a href="<?php echo $configuration['url'];?>"><?php echo $configuration['description'];?></a>');
            window.parent.$('#config_status').css('color','green');
            window.parent.$('#config_status').css('display','block');
            config_status_flag = 'green';
        <?php  
    }else{?>
    	   window.parent.$('#config_status').html('<img src="/SAFe/images/silk/stop.png" style="vertical-align:middle;"> <a href="<?php echo $configuration['url'];?>" style="color:red;"><?php echo $configuration['description'];?></a>');
           window.parent.$('#config_status').css('color','red');
           window.parent.$('#config_status').css('display','block');
           config_status_flag = 'red';
        <?php 
    };
} 
?>
</script>
<script type="text/javascript">
(function($){
	if(system_status_timer === null){
		//system_status_fresh(true,ajax_running_id);
		//system_status_timer = setInterval(function(){ajax_running_id = ajax_running_id+1;system_status_fresh(true,ajax_running_id);}, 5000);//5s
	}
})(jQuery);
</script> 
<script type='text/javascript'>
//check if the main page js was loaded.
function main_load_safe_js(){
	if ('undefined' !== typeof window.parent) {
		if ('undefined' == typeof window.parent.safe_message_box) {
		    //load css
			var css = window.parent.$("<link>");
		    css.attr({
		      rel:  "stylesheet",
		      type: "text/css",
		      href: "/SAFe/css/safe.css"
		    });
		    window.parent.$("head").append(css);
		    //load safe.js
			var head= window.parent.document.getElementsByTagName('head')[0];
		    var script= window.parent.document.createElement('script');
		    script.type= 'text/javascript';
		    script.src= '/SAFe/js/safe.js';
		    script.defer = true;
		    script.async = true;
		    head.appendChild(script);
		    script.onload=function() {
		    	//console.log('safe.js was loaded.');
		    }
		}
	}
}
$(document).ready(function(){
    if ('undefined' !== typeof window.parent) {
    	if(window.parent.$().jquery == '1.3.2'){
			// Load required javascript files
			window.parent.$.getScript("/SAFe/js/jquery/jquery-1.8.2.min.js", function(data, textStatus) {
			});
			window.parent.$.getScript("/SAFe/js/jquery-ui/jquery-ui-1.9.1.custom.min.js", function(data, textStatus) {
				main_load_safe_js();
			});
	   }else{
		   main_load_safe_js();
	   }
    }
});
</script>
<?php 
    echo $iframe_footer;      
?>
